<?php
/**
 * @file
 * adfs_standard.profile
 */

/**
 * Implements hook_form_FORM_ID_alter().
 *
 * Allows the profile to alter the site configuration form.
 *
 * @param array $form
 *   Nested array of form elements that comprise the form.
 * @param array $form_state
 *   A keyed array containing the current state of the form. The arguments that
 *   drupal_get_form() was originally called with are available in the array
 *   $form_state['build_info']['args'].
 */
function adfs_standard_form_install_configure_form_alter(&$form, $form_state) {
  // Pre-populate the site name with the server name.
  $form['site_information']['site_name']['#default_value'] = 'ADFS Standard';
  $form['admin_account']['account']['name']['#default_value'] = "admin";
}

/**
 * Implements hook_install_tasks().
 *
 * @return array
 *   A keyed array of tasks the profile will perform during the final stage of
 *   the installation.
 */
function adfs_standard_install_tasks() {
  return array(
    'adfs_standard_configure_site_features' => array(
      'display_name' => st('Configure site features'),
    ),
  );
}

/**
 * Implements a task added in adfs_standard_install_tasks above.
 */
function adfs_standard_configure_site_features() {
  // Revert features.
  $features = features_get_features();
  if (isset($features)) {
    foreach ($features as $name => $feature) {
      if ($feature->status) {
        features_revert(array($name => array('variable', 'user_permissions')));
      }
    }
  }

  cache_clear_all();

  // Admin theme.
  theme_enable(array('tao'));
  theme_enable(array('rubik'));
  variable_set('admin_theme', 'rubik');
  variable_set('node_admin_theme', 1);

  // Set default time zone.
  variable_set('date_default_timezone', 'Europe/Brussels');

  // Enable default permissions for system roles.
  user_role_grant_permissions(DRUPAL_ANONYMOUS_RID, array('access content'));
  user_role_grant_permissions(DRUPAL_AUTHENTICATED_RID, array('access content'));
}
